API Reference
=============

.. module:: facadedevice


Simple attributes
-----------------

.. autoclass:: local_attribute

.. autoclass:: logical_attribute


Remote attributes
-----------------

.. autoclass:: proxy_attribute

.. autoclass:: combined_attribute


State handling
--------------

.. autoclass:: state_attribute


Commands
--------

.. autoclass:: proxy_command


Facade base classes
-------------------

.. autoclass:: Facade

.. autoclass:: TimedFacade
